gsub

Function gsub 

pub fn gsub<'a>(
    state: &'a mut LuaState,
    s: &[u8],
    pat: &[u8],
    repl: &[u8],
) -> Result<Vec<u8>, LuaError>
Build a string from s by replacing pat with repl, push it on the stack, and return the bytes of the pushed string.

C: LUALIB_API const char *luaL_gsub(lua_State *L, const char *s, const char *p, const char *r)