lua_len

Function lua_len 

pub fn lua_len(state: &mut LuaState, idx: i32) -> Result<i64, LuaError>
Return the length of the value at idx as a i64, raising an error if the length is not an integer.

C: LUALIB_API lua_Integer luaL_len(lua_State *L, int idx)