push_where

Function push_where 

pub fn push_where(state: &mut LuaState, level: i32) -> Result<(), LuaError>
Push a string describing the location of the call at level onto the stack. If no location is available, pushes an empty string.