pub fn arg_error(
state: &mut LuaState,
arg: i32,
extramsg: &[u8],
) -> Result<usize, LuaError>Expand description
Push an error for argument arg with extra message extramsg.
Attempts to enrich the message with the calling function’s name.
Always returns Err.