get_metafield

Function get_metafield 

pub fn get_metafield(
    state: &mut LuaState,
    obj: i32,
    event: &[u8],
) -> Result<LuaType, LuaError>
Push the metafield event of obj onto the stack and return its type. If there is no metafield, nothing is pushed and LuaType::Nil is returned.