lua_ref

Function lua_ref 

pub fn lua_ref(state: &mut LuaState, t: i32) -> Result<i32, LuaError>
Store the value at the top of the stack in table t and return a unique integer reference. If the value is nil, returns LUA_REFNIL without modifying the table.