pub fn push_where(state: &mut LuaState, level: i32) -> Result<(), LuaError>Expand description
Push a string describing the location of the call at level onto the stack.
If no location is available, pushes an empty string.
C: LUALIB_API void luaL_where(lua_State *L, int level)