set_funcs

Function set_funcs 

pub fn set_funcs(
    state: &mut LuaState,
    l: &[LuaReg],
    nup: i32,
) -> Result<(), LuaError>
Register the functions in l into the table at -(nup + 1), giving each closure the nup upvalues currently at the top of the stack.

C: LUALIB_API void luaL_setfuncs(lua_State *L, const luaL_Reg *l, int nup)