pub fn co_resume(state: &mut LuaState) -> Result<usize, LuaError>Expand description
coroutine.resume(co [, val1, ...]) — attempt to resume coroutine co.
On success pushes true followed by all values yielded or returned by co.
On failure pushes false followed by the error object.