open_libs

Function open_libs 

pub fn open_libs(state: &mut LuaState) -> Result<(), LuaError>
Open all standard Lua libraries into state, registering each into the global table.

Corresponds to luaL_openlibs in linit.c. The true argument to require_lib means “set global”: the loaded module value is assigned to the global table under name, and the value left on the stack is then discarded.