pub fn io_write(state: &mut LuaState) -> Result<usize, LuaError>Expand description
io.write(...). C: io_write.
Writes all arguments to the current default output file (IO_OUTPUT). When
a file was set via io.output(filename), writes go to that file; otherwise
they go to stdout via state.write_output().
The borrow split (needing both &mut LuaState and &mut dyn LuaFileHandle)
is resolved by collecting all formatted strings first and then writing them
to the file handle obtained from the LSTREAM_REGISTRY.