gmatch

Function gmatch 

pub fn gmatch(state: &mut LuaState) -> Result<usize, LuaError>
string.gmatch(s, pattern [, init]) — return an iterator for all matches.

PORT NOTE: C uses lua_newuserdatauv for the GMatchState plus a 3-upvalue C closure. Phase-A LuaCClosure upvalues are immutable, so we collapse the state into a 4-element Lua table held in a single upvalue (see gmatch_aux).